package Test2::Workflow::Task::Action;
use strict;
use warnings;

our $VERSION = '0.000159';

use base 'Test2::Workflow::Task';
use Test2::Util::HashBase qw/around/;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Test2::Workflow::Task::Action - Encapsulation of an action.

=head1 SOURCE

The source code repository for Test2-Workflow can be found at
F<https://github.com/Test-More/Test2-Suite/>.

=head1 MAINTAINERS

=over 4

=item Chad Granum E<lt>exodist@cpan.orgE<gt>

=back

=head1 AUTHORS

=over 4

=item Chad Granum E<lt>exodist@cpan.orgE<gt>

=back

=head1 COPYRIGHT

Copyright 2018 Chad Granum E<lt>exodist7@gmail.comE<gt>.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

See F<http://dev.perl.org/licenses/>

=cut

